==> zio-aws-appmesh_3-5.17.104.3-sources.jar: zio/aws/appmesh/model/DescribeVirtualNodeRequest.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.appmesh.model.primitives.{AccountId, ResourceName}
import scala.jdk.CollectionConverters.*
final case class DescribeVirtualNodeRequest(
    meshName: ResourceName,
    meshOwner: Option[AccountId] = None,
    virtualNodeName: ResourceName
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.DescribeVirtualNodeRequest = {
    import DescribeVirtualNodeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.DescribeVirtualNodeRequest
      .builder()
      .meshName(ResourceName.unwrap(meshName): java.lang.String)
      .optionallyWith(
        meshOwner.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.meshOwner)
      .virtualNodeName(ResourceName.unwrap(virtualNodeName): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.DescribeVirtualNodeRequest.ReadOnly =
    zio.aws.appmesh.model.DescribeVirtualNodeRequest.wrap(buildAwsValue())
}
object DescribeVirtualNodeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.DescribeVirtualNodeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.DescribeVirtualNodeRequest =
      zio.aws.appmesh.model.DescribeVirtualNodeRequest(
        meshName,
        meshOwner.map(value => value),
        virtualNodeName
      )
    def meshName: ResourceName
    def meshOwner: Option[AccountId]
    def virtualNodeName: ResourceName
    def getMeshName: ZIO[Any, Nothing, ResourceName] = ZIO.succeed(meshName)
    def getMeshOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("meshOwner", meshOwner)
    def getVirtualNodeName: ZIO[Any, Nothing, ResourceName] =
      ZIO.succeed(virtualNodeName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.DescribeVirtualNodeRequest
  ) extends zio.aws.appmesh.model.DescribeVirtualNodeRequest.ReadOnly {
    override val meshName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.meshName())
    override val meshOwner: Option[AccountId] = scala
      .Option(impl.meshOwner())
      .map(value => zio.aws.appmesh.model.primitives.AccountId(value))
    override val virtualNodeName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.virtualNodeName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.DescribeVirtualNodeRequest
  ): zio.aws.appmesh.model.DescribeVirtualNodeRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-appmesh_3-5.17.170.1-sources.jar: zio/aws/appmesh/model/DescribeVirtualNodeRequest.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.appmesh.model.primitives.{AccountId, ResourceName}
import scala.jdk.CollectionConverters.*
final case class DescribeVirtualNodeRequest(
    meshName: ResourceName,
    meshOwner: Optional[AccountId] = Optional.Absent,
    virtualNodeName: ResourceName
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.DescribeVirtualNodeRequest = {
    import DescribeVirtualNodeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.DescribeVirtualNodeRequest
      .builder()
      .meshName(ResourceName.unwrap(meshName): java.lang.String)
      .optionallyWith(
        meshOwner.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.meshOwner)
      .virtualNodeName(ResourceName.unwrap(virtualNodeName): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.DescribeVirtualNodeRequest.ReadOnly =
    zio.aws.appmesh.model.DescribeVirtualNodeRequest.wrap(buildAwsValue())
}
object DescribeVirtualNodeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.DescribeVirtualNodeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.DescribeVirtualNodeRequest =
      zio.aws.appmesh.model.DescribeVirtualNodeRequest(
        meshName,
        meshOwner.map(value => value),
        virtualNodeName
      )
    def meshName: ResourceName
    def meshOwner: Optional[AccountId]
    def virtualNodeName: ResourceName
    def getMeshName: ZIO[Any, Nothing, ResourceName] = ZIO.succeed(meshName)
    def getMeshOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("meshOwner", meshOwner)
    def getVirtualNodeName: ZIO[Any, Nothing, ResourceName] =
      ZIO.succeed(virtualNodeName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.DescribeVirtualNodeRequest
  ) extends zio.aws.appmesh.model.DescribeVirtualNodeRequest.ReadOnly {
    override val meshName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.meshName())
    override val meshOwner: Optional[AccountId] = zio.aws.core.internal
      .optionalFromNullable(impl.meshOwner())
      .map(value => zio.aws.appmesh.model.primitives.AccountId(value))
    override val virtualNodeName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.virtualNodeName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.DescribeVirtualNodeRequest
  ): zio.aws.appmesh.model.DescribeVirtualNodeRequest.ReadOnly = new Wrapper(
    impl
  )
}
